@@ -40,6 +40,7 @@ typedef struct
 {
   XfceShortcutsEditor *editor;
   XfceGtkActionEntry  *entry;
+  const gchar         *displayed_label;
 } ShortcutEditClickedData;
 
 typedef struct
@@ -57,13 +58,6 @@ typedef struct
   gchar          *other_path;
 } ShortcutInfo;
 
-typedef struct
-{
-  gchar              *section_name;
-  XfceGtkActionEntry *entries;
-  size_t              size;
-} Section;
-
 
 
 static void     xfce_shortcuts_editor_finalize                 (GObject                   *object);
@@ -96,8 +90,8 @@ struct _XfceShortcutsEditor
 {
   GtkVBox             __parent__;
 
-  Section *arrays;
-  size_t  arrays_count;
+  XfceShortcutsEditorSection *arrays;
+  size_t                      arrays_count;
 };
 
 
@@ -112,7 +106,10 @@ xfce_shortcuts_editor_class_init (XfceShortcutsEditorClass *klass)
   GObjectClass *gobject_class;
 
   /* Make sure to use the translations from libxfce4ui */
-  xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
+  bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
 
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = xfce_shortcuts_editor_finalize;
@@ -167,6 +164,43 @@ xfce_shortcuts_editor_new (int argument_count, ...)
 
 
 
+/**
+ * xfce_shortcuts_editor_new_array:
+ * @sections   : an array of XfceShortcutsEditorSection triads (see
+ *               xfce_shortcuts_editor_new_variadic for a description).
+ * @n_sections : #int, the size of the array.
+ *
+ * A vectorized version of xfce_shortcuts_editor_new.
+ *
+ * Since: 4.17.5
+ **/
+GtkWidget*
+xfce_shortcuts_editor_new_array (XfceShortcutsEditorSection *sections,
+                                 int                         n_sections)
+{
+  XfceShortcutsEditor *editor;
+
+  editor = g_object_new (XFCE_TYPE_SHORTCUTS_EDITOR, NULL);
+
+  editor->arrays_count = n_sections;
+  editor->arrays = g_new (XfceShortcutsEditorSection, n_sections);
+
+  for (int i = 0; i < n_sections; i++)
+    {
+      editor->arrays[i].section_name = g_strdup (sections[i].section_name);
+      editor->arrays[i].entries = sections[i].entries;
+      editor->arrays[i].size = sections[i].size;
+    }
+
+  xfce_shortcuts_editor_create_contents (editor);
+
+  gtk_widget_show (GTK_WIDGET (editor));
+
+  return GTK_WIDGET (editor);
+}
+
+
+
 /**
  * xfce_shortcuts_editor_new_variadic:
  * @argument_count : #int, the number of arguments, including this one.
@@ -177,7 +211,8 @@ xfce_shortcuts_editor_new (int argument_count, ...)
  * The @argument_list consists of triads of arguments.
  * The types of a triad are the following: (gchar*, XfceGtkActionEntry[], size_t).
  *
- * The first member of a triad is the name of the section in the editor.
+ * The first member of a triad is the name of the section in the editor. Specify
+ * %NULL or an empty string so that no section appears.
  * The second member of a triad is the array of XfceGtkActionEntries which are
  * used to handle the shortcuts.
  * The third member is the size of that array.
@@ -196,11 +231,11 @@ xfce_shortcuts_editor_new_variadic (int     argument_count,
   editor = g_object_new (XFCE_TYPE_SHORTCUTS_EDITOR, NULL);
 
   editor->arrays_count = (argument_count - 1) / 3;
-  editor->arrays = g_malloc (sizeof (Section) * editor->arrays_count);
+  editor->arrays = g_malloc (sizeof (XfceShortcutsEditorSection) * editor->arrays_count);
 
   for (int i = 0; i * 3 + 1 < argument_count; i++)
     {
-      editor->arrays[i].section_name = strdup (va_arg (argument_list, gchar*));
+      editor->arrays[i].section_name = g_strdup (va_arg (argument_list, gchar*));
       editor->arrays[i].entries = va_arg (argument_list, XfceGtkActionEntry*);
       editor->arrays[i].size = va_arg (argument_list, size_t);
     }
@@ -280,7 +315,7 @@ xfce_shortcuts_editor_create_contents (XfceShortcutsEditor *editor)
         }
 
       /* section name */
-      if (g_strcmp0 (editor->arrays[array_idx].section_name, "") != 0)
+      if (! xfce_str_is_empty (editor->arrays[array_idx].section_name))
         {
           label  = gtk_label_new ("");
           markup = g_strconcat ("<b>", editor->arrays[array_idx].section_name, "</b>", NULL);
@@ -319,8 +354,9 @@ xfce_shortcuts_editor_create_contents (XfceShortcutsEditor *editor)
           reset_data = malloc (sizeof (ShortcutOtherClickedData));
 
           label = gtk_label_new_with_mnemonic (entry.menu_item_label_text);
+          data->displayed_label = gtk_label_get_text (GTK_LABEL (label));
           gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
-          gtk_widget_set_tooltip_text (label, gtk_label_get_text (GTK_LABEL (label))); /* this way mnemonics are removed */
+          gtk_widget_set_tooltip_text (label, data->displayed_label);
           gtk_widget_set_hexpand (label, TRUE);
           gtk_widget_set_halign (label, GTK_ALIGN_START);
           gtk_widget_set_margin_start (label, 10);
@@ -467,7 +503,7 @@ xfce_shortcuts_editor_shortcut_clicked (GtkWidget               *widget,
   guint            accel_key;
   gchar           *label;
 
-  dialog = xfce_shortcut_dialog_new ("", data->entry->menu_item_label_text, "");
+  dialog = xfce_shortcut_dialog_new ("", data->displayed_label, "");
 
   g_signal_connect (dialog, "validate-shortcut", G_CALLBACK (xfce_shortcuts_editor_validate_shortcut), data);
 
