@@ -64,6 +64,7 @@ struct _XfceGtkActionEntry
   const gchar     *menu_item_icon_name;    /* optional icon name which will be used to find a image for the item */
 
   GCallback        callback;               /* The callback which will be triggered on activation */
+                                           /* The callback has to return TRUE to signal that the accelerator was activated and handled */
 };
 typedef struct _XfceGtkActionEntry XfceGtkActionEntry;
 
@@ -138,6 +139,7 @@ gboolean                  xfce_gtk_execute_tab_accel                      (const
                                                                            XfceGtkActionEntry       *entries,
                                                                            size_t                    entry_count);
 void                      xfce_gtk_menu_append_seperator                  (GtkMenuShell             *menu);
+void                      xfce_gtk_menu_append_separator                  (GtkMenuShell             *menu);
 
 GtkWidget                *xfce_gtk_button_new_mixed                       (const gchar              *stock_id,
                                                                            const gchar              *label) G_GNUC_MALLOC;
