@@ -558,6 +558,34 @@ get_gpu_info (guint *num_gpus)
 
 
 
+/**
+ * @string: A string which might be quoted with ' or ".
+ *
+ * Unquotes the given string if both leading and trailing quotes are present,
+ * and if the quotes are of the same type (single or double).
+ * The returned string has to be freed with g_free() when no longer needed. 
+ *
+ * Return value: A newly-allocated, unquoted string.
+ */
+static gchar *
+unquote_string (const gchar *string)
+{
+  gint size = 0;
+
+  if ((g_str_has_prefix (string, "\"") && g_str_has_suffix (string, "\""))
+      || (g_str_has_prefix (string, "\'") && g_str_has_suffix (string, "\'")))
+    {
+      string += 1;
+      size -= 1;
+    }
+
+  size += strlen (string);
+
+  return g_strndup (string, size);
+}
+
+
+
 static GHashTable*
 get_os_info (void)
 {
@@ -585,7 +613,6 @@ get_os_info (void)
 
           if (delimiter != NULL)
             {
-              gint size;
               gchar *key, *value;
 
               key = g_strndup (lines[i], delimiter - lines[i]);
@@ -593,17 +620,7 @@ get_os_info (void)
               /* Jump the '=' */
               delimiter += strlen ("=");
 
-              /* Eventually jump the ' " ' character */
-              if (g_str_has_prefix (delimiter, "\""))
-                delimiter += strlen ("\"");
-
-              size = strlen (delimiter);
-
-              /* Don't consider the last ' " ' too */
-              if (g_str_has_suffix (delimiter, "\""))
-                size -= strlen ("\"");
-
-              value = g_strndup (delimiter, size);
+              value = unquote_string (delimiter);
 
               g_hash_table_insert (hashtable, key, value);
             }
